FAGConfig class

Constructors

FAGConfig({String? outputDir, bool? autoDetection, bool? namedWithParent, String? outputFilename, String? className, String? filenameSplitPattern, List<String>? includePaths, List<String>? excludePaths, bool? leadingWithPackageName, bool? uniqifyName})
FAGConfig.fromJson(Map<String, dynamic> json)
factory
FAGConfig.fromRawJson(String str)
factory

Properties

autoDetection bool?
getter/setter pair
className String?
getter/setter pair
excludePaths List<String>?
getter/setter pair
filenameSplitPattern String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includePaths List<String>?
getter/setter pair
leadingWithPackageName bool?
getter/setter pair
namedWithParent bool?
getter/setter pair
outputDir String?
getter/setter pair
outputFilename String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uniqifyName bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited