FAGGenerator class
Constructors
-
FAGGenerator({required String packageName, required List<
String> filePaths, required String configJSONString})
Properties
- config ↔ FAGConfig
-
getter/setter pair
- configJSONString → String
-
final
- existingVarNames ↔ Set
-
getter/setter pair
-
filePaths
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
adjustFirstLetterCase(
String str, bool capitalize) → String -
convertAllExtensionsToCamelCase(
String filePath) → String - 将所有扩展名层级转换为驼峰形式
-
formatName(
{required String name, required bool isDir}) → String -
generateOneLine(
{required String path}) → String -
generateVarName(
{required String path, required int startIndex, required String regexPattern}) → String -
isExcludePath(
String filePath) → bool -
isIncludePath(
String filePath) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → String -
toString(
) → String -
A string representation of this object.
inherited
-
transformString(
String inputString, String regexPattern) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited